# Dronefly Discord

This library will support writing Discord cogs based on
[dronefly-core](https://github.com/dronefly-garden/dronefly-core). It is
derived from the Discord-specific code extracted from the original
[Dronefly](https://dronefly.readthedocs.io) bot codebase. We aim to keep
the library general enough to work with any bot based on
[discord.py](https://discordpy.readthedocs.io), as well as on bots using
the [Red-DiscordBot](https://docs.discord.red) framework.

# Related packages

## Dronefly core

The [dronefly-core](https://github.com/dronefly-garden/dronefly-core)
package is an incomplete rewrite of [Dronefly](https://dronefly.readthedocs.io/)
Discord bot's core components.

## Dronefly Discord bot

Dronefly Discord bot brings [iNaturalist](https://www.inaturalist.org) taxa,
observations, and other data from the site into conversations on the
[Discord](https://discord.com) chat platform.
